==> haskell-recv-0.1.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.1
visibility:           public
id:                   recv-0.1.1-FjfDzF7uQzS6sGPp31IBJG
key:                  recv-0.1.1-FjfDzF7uQzS6sGPp31IBJG
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  ce21f3b6c4e60afa51423779ea1eb2ca
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.1-FjfDzF7uQzS6sGPp31IBJG
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-Clrm8B2IBAjIFHTKmEcInu

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recv-0.1.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.1
visibility:           public
id:                   recv-0.1.1-DgOW8knDUdDCn5T0lctn0D
key:                  recv-0.1.1-DgOW8knDUdDCn5T0lctn0D
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  33f994b1ebd30b112d4e6988b8cd03f4
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.1-DgOW8knDUdDCn5T0lctn0D
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-ASj1hBk5tU17JSnFMFmeWy

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
